==> jc-1.4.0.tar.gz: polyglot/ext/jl/Version.c <==
// public class polyglot.ext.jl.Version

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class fb81e052aafe4b1f polyglot_ext_jl_Version
// @dep_class 4ba1325a7aefecac polyglot_main_Version

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_ext_jl_Version

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/ext/jl/Version.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_polyglot_ext_jl_Version$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, _init$52f4ad9f2989aeee);

void
_jc_polyglot_ext_jl_Version$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(6);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public int major()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$major$11e120a477900a2f[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$major$11e120a477900a2f[] = { 
_JC_TYPE_INT };

_jc_method _jc_polyglot_ext_jl_Version$method_info$major$11e120a477900a2f = {
	.name=			"major",
	.signature=		"()I",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$major$11e120a477900a2f,
	.signature_hash=	_JC_JLONG(0x11e120a477900a2f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.major$11e120a477900a2f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$major$11e120a477900a2f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, major$11e120a477900a2f);

jint
_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(10);				// 0
	return 1;
}

//
// public int minor()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$minor$206704e7c95168d6[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$minor$206704e7c95168d6[] = { 
_JC_TYPE_INT };

_jc_method _jc_polyglot_ext_jl_Version$method_info$minor$206704e7c95168d6 = {
	.name=			"minor",
	.signature=		"()I",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$minor$206704e7c95168d6,
	.signature_hash=	_JC_JLONG(0x206704e7c95168d6),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.minor$206704e7c95168d6) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$minor$206704e7c95168d6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, minor$206704e7c95168d6);

jint
_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(12);				// 0
	return 1;
}

//
// public java.lang.String name()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$name$e6acce026cadf81e[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$name$e6acce026cadf81e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_ext_jl_Version$method_info$name$e6acce026cadf81e = {
	.name=			"name",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$name$e6acce026cadf81e,
	.signature_hash=	_JC_JLONG(0xe6acce026cadf81e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.name$e6acce026cadf81e) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$name$e6acce026cadf81e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, name$e6acce026cadf81e);

_jc_java_lang_String$object *
_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(8);				// 0
	return _JC_STRING(env, "jl");
}

//
// public int patch_level()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$patch__5flevel$c3db817585344b9f[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$patch__5flevel$c3db817585344b9f[] = { 
_JC_TYPE_INT };

_jc_method _jc_polyglot_ext_jl_Version$method_info$patch__5flevel$c3db817585344b9f = {
	.name=			"patch_level",
	.signature=		"()I",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$patch__5flevel$c3db817585344b9f,
	.signature_hash=	_JC_JLONG(0xc3db817585344b9f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.patch__5flevel$c3db817585344b9f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$patch__5flevel$c3db817585344b9f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, patch__5flevel$c3db817585344b9f);

jint
_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(14);				// 0
	return 0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_ext_jl_Version$methods[] = {
	&_jc_polyglot_ext_jl_Version$method_info$_init$52f4ad9f2989aeee,
	&_jc_polyglot_ext_jl_Version$method_info$major$11e120a477900a2f,
	&_jc_polyglot_ext_jl_Version$method_info$minor$206704e7c95168d6,
	&_jc_polyglot_ext_jl_Version$method_info$name$e6acce026cadf81e,
	&_jc_polyglot_ext_jl_Version$method_info$patch__5flevel$c3db817585344b9f
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_ext_jl_Version$instanceof_hash_bucket_31[] = {
	&_jc_polyglot_ext_jl_Version$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ext_jl_Version$instanceof_hash_bucket_44[] = {
	&_jc_polyglot_main_Version$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ext_jl_Version$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_ext_jl_Version$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[31]=	_jc_polyglot_ext_jl_Version$instanceof_hash_bucket_31,
	[44]=	_jc_polyglot_ext_jl_Version$instanceof_hash_bucket_44,
	[113]=	_jc_polyglot_ext_jl_Version$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_ext_jl_Version$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "polyglot/main/Version",	_JC_JLONG(0x4ba1325a7aefecac) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_ext_jl_Version$vtype _jc_polyglot_ext_jl_Version$type = {
    .type= {
	.name=			"polyglot/ext/jl/Version",
	.superclass=		&_jc_polyglot_main_Version$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		20,
		.hash=			_JC_JLONG(0xfb81e052aafe4b1f),
		.source_file=		"Version.java",
		.instance_size=		sizeof(_jc_polyglot_ext_jl_Version$refs) + sizeof(_jc_polyglot_ext_jl_Version$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_polyglot_ext_jl_Version$methods) / sizeof(*_jc_polyglot_ext_jl_Version$methods),
		.methods=		_jc_polyglot_ext_jl_Version$methods,
		.instanceof_hash_table=	_jc_polyglot_ext_jl_Version$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_ext_jl_Version$class_depends) / sizeof(*_jc_polyglot_ext_jl_Version$class_depends),
		.class_depends=		_jc_polyglot_ext_jl_Version$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_main_Version$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_main_Version= {
	    .major$11e120a477900a2f=			// overridden
		&_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f,
	    .minor$206704e7c95168d6=			// overridden
		&_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6,
	    .name$e6acce026cadf81e=				// overridden
		&_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e,
	    .patch__5flevel$c3db817585344b9f=		// overridden
		&_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f,
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_main_Version$method$toString$7ea43b33b80a3070,
	},
	.polyglot_ext_jl_Version= {
	    .major$11e120a477900a2f=
		&_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f,
	    .minor$206704e7c95168d6=
		&_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6,
	    .name$e6acce026cadf81e=
		&_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e,
	    .patch__5flevel$c3db817585344b9f=
		&_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f,
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/ext/jl/Version.c <==
// public class polyglot.ext.jl.Version

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class fb81e052aafe4b1f polyglot_ext_jl_Version
// @dep_class 4ba1325a7aefecac polyglot_main_Version

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_ext_jl_Version

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/ext/jl/Version.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_polyglot_ext_jl_Version$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_polyglot_ext_jl_Version$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(6);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public int major()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$major$11e120a477900a2f[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$major$11e120a477900a2f[] = { 
_JC_TYPE_INT };

_jc_method _jc_polyglot_ext_jl_Version$method_info$major$11e120a477900a2f = {
	.name=			"major",
	.signature=		"()I",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$major$11e120a477900a2f,
	.signature_hash=	_JC_JLONG(0x11e120a477900a2f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.major$11e120a477900a2f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$major$11e120a477900a2f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, major$11e120a477900a2f);

jint _JC_JCNI_ATTR
_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(10);				// 0
	return 1;
}

//
// public int minor()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$minor$206704e7c95168d6[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$minor$206704e7c95168d6[] = { 
_JC_TYPE_INT };

_jc_method _jc_polyglot_ext_jl_Version$method_info$minor$206704e7c95168d6 = {
	.name=			"minor",
	.signature=		"()I",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$minor$206704e7c95168d6,
	.signature_hash=	_JC_JLONG(0x206704e7c95168d6),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.minor$206704e7c95168d6) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$minor$206704e7c95168d6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, minor$206704e7c95168d6);

jint _JC_JCNI_ATTR
_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(12);				// 0
	return 1;
}

//
// public java.lang.String name()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$name$e6acce026cadf81e[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$name$e6acce026cadf81e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_ext_jl_Version$method_info$name$e6acce026cadf81e = {
	.name=			"name",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$name$e6acce026cadf81e,
	.signature_hash=	_JC_JLONG(0xe6acce026cadf81e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.name$e6acce026cadf81e) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$name$e6acce026cadf81e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, name$e6acce026cadf81e);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(8);				// 0
	return _JC_STRING(env, "jl");
}

//
// public int patch_level()
//

static _jc_linenum _jc_polyglot_ext_jl_Version$linenum_table$patch__5flevel$c3db817585344b9f[];

static const unsigned char _jc_polyglot_ext_jl_Version$param_ptypes$patch__5flevel$c3db817585344b9f[] = { 
_JC_TYPE_INT };

_jc_method _jc_polyglot_ext_jl_Version$method_info$patch__5flevel$c3db817585344b9f = {
	.name=			"patch_level",
	.signature=		"()I",
	.class=			&_jc_polyglot_ext_jl_Version$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Version$param_ptypes$patch__5flevel$c3db817585344b9f,
	.signature_hash=	_JC_JLONG(0xc3db817585344b9f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ext_jl_Version$vtable, polyglot_ext_jl_Version.patch__5flevel$c3db817585344b9f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Version$linenum_table$patch__5flevel$c3db817585344b9f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Version, patch__5flevel$c3db817585344b9f);

jint _JC_JCNI_ATTR
_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f(_jc_env *const env, _jc_polyglot_ext_jl_Version$object *this)
{
	struct _jc_polyglot_ext_jl_Version$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(14);				// 0
	return 0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_ext_jl_Version$methods[] = {
	&_jc_polyglot_ext_jl_Version$method_info$_init$52f4ad9f2989aeee,
	&_jc_polyglot_ext_jl_Version$method_info$major$11e120a477900a2f,
	&_jc_polyglot_ext_jl_Version$method_info$minor$206704e7c95168d6,
	&_jc_polyglot_ext_jl_Version$method_info$name$e6acce026cadf81e,
	&_jc_polyglot_ext_jl_Version$method_info$patch__5flevel$c3db817585344b9f
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_ext_jl_Version$instanceof_hash_bucket_31[] = {
	&_jc_polyglot_ext_jl_Version$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ext_jl_Version$instanceof_hash_bucket_44[] = {
	&_jc_polyglot_main_Version$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ext_jl_Version$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_ext_jl_Version$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[31]=	_jc_polyglot_ext_jl_Version$instanceof_hash_bucket_31,
	[44]=	_jc_polyglot_ext_jl_Version$instanceof_hash_bucket_44,
	[101]=	_jc_polyglot_ext_jl_Version$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_ext_jl_Version$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "polyglot/main/Version",	_JC_JLONG(0x4ba1325a7aefecac) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_ext_jl_Version$vtype _jc_polyglot_ext_jl_Version$type = {
    .type= {
	.name=			"polyglot/ext/jl/Version",
	.superclass=		&_jc_polyglot_main_Version$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		20,
		.hash=			_JC_JLONG(0xfb81e052aafe4b1f),
		.source_file=		"Version.java",
		.instance_size=		sizeof(_jc_polyglot_ext_jl_Version$refs) + sizeof(_jc_polyglot_ext_jl_Version$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_polyglot_ext_jl_Version$methods) / sizeof(*_jc_polyglot_ext_jl_Version$methods),
		.methods=		_jc_polyglot_ext_jl_Version$methods,
		.instanceof_hash_table=	_jc_polyglot_ext_jl_Version$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_ext_jl_Version$class_depends) / sizeof(*_jc_polyglot_ext_jl_Version$class_depends),
		.class_depends=		_jc_polyglot_ext_jl_Version$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_main_Version$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_main_Version= {
	    .major$11e120a477900a2f=			// overridden
		&_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f,
	    .minor$206704e7c95168d6=			// overridden
		&_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6,
	    .name$e6acce026cadf81e=				// overridden
		&_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e,
	    .patch__5flevel$c3db817585344b9f=		// overridden
		&_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f,
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_main_Version$method$toString$7ea43b33b80a3070,
	},
	.polyglot_ext_jl_Version= {
	    .major$11e120a477900a2f=
		&_jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f,
	    .minor$206704e7c95168d6=
		&_jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6,
	    .name$e6acce026cadf81e=
		&_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e,
	    .patch__5flevel$c3db817585344b9f=
		&_jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f,
	},
    }
};
